##  Delinking a Fact Sheet to Stop Synchronization
To stop the synchronization between a fact sheet and the SAP Cloud ALM project, follow these steps:
  1. Go to the Agile Tracking tab of the fact sheet.
  2. Click the three-dot menu in the top right corner.
  3. Select Remove From Sync.
